@@ -14,7 +14,7 @@ Contributors:
    Roger Light - initial implementation and documentation.
 */
 
-#define _POSIX_C_SOURCE 200809L
+#include "config.h"
 
 #include <assert.h>
 #include <errno.h>
