@@ -14,7 +14,7 @@ Contributors:
    Roger Light - initial implementation and documentation.
 */
 
-#define _POSIX_C_SOURCE 200809L
+#include "config.h"
 
 #include <assert.h>
 #include <errno.h>
@@ -30,6 +30,10 @@ Contributors:
 #define snprintf sprintf_s
 #endif
 
+#ifdef __APPLE__
+#  include <sys/time.h>
+#endif
+
 #include <mosquitto.h>
 #include "client_shared.h"
 
@@ -38,6 +42,8 @@ static int get_time(struct tm **ti, long *ns)
 {
 #ifdef WIN32
 	SYSTEMTIME st;
+#elif defined(__APPLE__)
+	struct timeval tv;
 #else
 	struct timespec ts;
 #endif
@@ -48,6 +54,10 @@ static int get_time(struct tm **ti, long *ns)
 
 	GetLocalTime(&st);
 	*ns = st.wMilliseconds*1000000L;
+#elif defined(__APPLE__)
+	gettimeofday(&tv, NULL);
+	s = tv.tv_sec;
+	*ns = tv.tv_usec*1000;
 #else
 	if(clock_gettime(CLOCK_REALTIME, &ts) != 0){
 		fprintf(stderr, "Error obtaining system time.\n");
