@@ -19,8 +19,8 @@
 #  ifndef strcasecmp
 #    define strcasecmp strcmpi
 #  endif
-#define strtok_r strtok_s
-#define strerror_r(e, b, l) strerror_s(b, l, e)
+#  define strtok_r strtok_s
+#  define strerror_r(e, b, l) strerror_s(b, l, e)
 #endif
 
 
@@ -29,7 +29,12 @@
 
 #ifdef __APPLE__
 #  define __DARWIN_C_SOURCE
+#elif defined(__FreeBSD__) || defined(__NetBSD__) || defined(__SYMBIAN32__) || defined(__QNX__)
+#  define _XOPEN_SOURCE 700
+#  define __BSD_VISIBLE 1
+#  define HAVE_NETINET_IN_H
 #else
+#  define _XOPEN_SOURCE 700
 #  define _DEFAULT_SOURCE 1
 #  define _POSIX_C_SOURCE 200809L
 #endif
