@@ -14,6 +14,8 @@ Contributors:
    Roger Light - initial implementation and documentation.
 */
 
+#include "config.h"
+
 #ifdef WITH_SRV
 #  include <ares.h>
 
@@ -44,7 +46,7 @@ static void srv_callback(void *arg, int status, int timeouts, unsigned char *abu
 		pthread_mutex_lock(&mosq->callback_mutex);
 		if(mosq->on_disconnect){
 			mosq->in_callback = true;
-			mosq->on_disconnect(mosq, mosq->userdata, 2);
+			mosq->on_disconnect(mosq, mosq->userdata, MOSQ_ERR_LOOKUP);
 			mosq->in_callback = false;
 		}
 		pthread_mutex_unlock(&mosq->callback_mutex);
