@@ -13,8 +13,8 @@ and the Eclipse Distribution License is available at
 Contributors:
    Roger Light - initial implementation and documentation.
 */
-#ifndef _UTIL_MOSQ_H_
-#define _UTIL_MOSQ_H_
+#ifndef UTIL_MOSQ_H
+#define UTIL_MOSQ_H
 
 #include <stdio.h>
 
@@ -22,20 +22,19 @@ Contributors:
 #include "mosquitto.h"
 #include "mosquitto_internal.h"
 #ifdef WITH_BROKER
-#  include "mosquitto_broker.h"
+#  include "mosquitto_broker_internal.h"
 #endif
 
-int _mosquitto_packet_alloc(struct _mosquitto_packet *packet);
 #ifdef WITH_BROKER
-void _mosquitto_check_keepalive(struct mosquitto_db *db, struct mosquitto *mosq);
+void mosquitto__check_keepalive(struct mosquitto_db *db, struct mosquitto *mosq);
 #else
-void _mosquitto_check_keepalive(struct mosquitto *mosq);
+void mosquitto__check_keepalive(struct mosquitto *mosq);
 #endif
-uint16_t _mosquitto_mid_generate(struct mosquitto *mosq);
-FILE *_mosquitto_fopen(const char *path, const char *mode, bool restrict_read);
+uint16_t mosquitto__mid_generate(struct mosquitto *mosq);
+FILE *mosquitto__fopen(const char *path, const char *mode, bool restrict_read);
 
-#ifdef REAL_WITH_TLS_PSK
-int _mosquitto_hex2bin(const char *hex, unsigned char *bin, int bin_max_len);
+#ifdef WITH_TLS_PSK
+int mosquitto__hex2bin(const char *hex, unsigned char *bin, int bin_max_len);
 #endif
 
 #endif
