@@ -14,7 +14,8 @@ Contributors:
    Roger Light - initial implementation and documentation.
 */
 
-#include <config.h>
+#include "config.h"
+
 #include <stdio.h>
 #include <string.h>
 
