@@ -279,6 +279,12 @@ int add__acl_pattern(struct mosquitto__security_options *security_opts, const ch
 		}
 	}
 
+	if(acl->ccount == 0 && acl->ucount == 0){
+		log__printf(NULL, MOSQ_LOG_WARNING,
+				"Warning: ACL pattern '%s' does not contain '%%c' or '%%u'.",
+				topic);
+	}
+
 	if(security_opts->acl_patterns){
 		acl_tail = security_opts->acl_patterns;
 		while(acl_tail->next){
@@ -303,6 +309,7 @@ int mosquitto_acl_check_default(struct mosquitto_db *db, struct mosquitto *conte
 	struct mosquitto__security_options *security_opts = NULL;
 
 	if(!db || !context || !topic) return MOSQ_ERR_INVAL;
+	if(context->bridge) return MOSQ_ERR_SUCCESS;
 
 	if(db->config->per_listener_settings){
 		if(!context->listener) return MOSQ_ERR_ACL_DENIED;
@@ -314,7 +321,6 @@ int mosquitto_acl_check_default(struct mosquitto_db *db, struct mosquitto *conte
 			return MOSQ_ERR_PLUGIN_DEFER;
 	}
 
-	if(context->bridge) return MOSQ_ERR_SUCCESS;
 	if(access == MOSQ_ACL_SUBSCRIBE) return MOSQ_ERR_SUCCESS; /* FIXME - implement ACL subscription strings. */
 	if(!context->acl_list && !security_opts->acl_patterns) return MOSQ_ERR_ACL_DENIED;
 
