@@ -27,16 +27,14 @@ broker = mosq_test.start_broker(filename=os.path.basename(__file__))
 
 try:
     sock = mosq_test.do_client_connect(connect_packet, connack_packet)
-    sock.send(publish_packet)
+    mosq_test.do_send_receive(sock, publish_packet, pubrec_packet, "pubrec")
+
+    # Timeout is 8 seconds which means the broker should repeat the PUBREC.
 
     if mosq_test.expect_packet(sock, "pubrec", pubrec_packet):
-        # Timeout is 8 seconds which means the broker should repeat the PUBREC.
+        mosq_test.do_send_receive(sock, pubrel_packet, pubcomp_packet, "pubcomp")
 
-        if mosq_test.expect_packet(sock, "pubrec", pubrec_packet):
-            sock.send(pubrel_packet)
-
-            if mosq_test.expect_packet(sock, "pubcomp", pubcomp_packet):
-                rc = 0
+        rc = 0
 
     sock.close()
 finally:
