@@ -17,7 +17,7 @@ def write_config(filename, port1, port2):
         f.write("port %d\n" % (port2))
         f.write("\n")
         f.write("connection bridge_test\n")
-        f.write("address localhost:%d\n" % (port1))
+        f.write("address 127.0.0.1:%d\n" % (port1))
         f.write("topic bridge/# both 0\n")
         f.write("notifications false\n")
         f.write("restart_timeout 2\n")
